@@ -1,4 +1,5 @@
-yaml = '''loki:
+yaml = '''
+loki:
   # image:
   #   pullPolicy: IfNotPresent
   #   repository: grafana/loki
@@ -24,4 +25,5 @@ promtail:
       memory: 400Mi
     requests:
       cpu: 200m
-      memory: 200Mi'''
+      memory: 200Mi
+'''
