@@ -11,14 +11,15 @@ def get_file(path: str) -> str:
         response.close()
         content = response.content
     else:
-        file_path = os.path.abspath(
-            os.path.join(os.path.abspath(__file__), os.pardir, os.pardir, os.pardir, path)
-        )
-        file = open(file_path)
+        file = open(path)
         content = file.read()
     return content
 
 
+def check_file(path: str) -> bool:
+    return os.path.exists(path)
+
+
 def get_yaml_config(path: str) -> Iterator[dict]:
     yaml_text = get_file(path)
     return yaml.safe_load_all(yaml_text)
@@ -44,6 +45,14 @@ def read_value(question: str, prompt: str = '', default_value: str = '') -> str:
     return value
 
 
+def yes_no_input(message: str, yes_by_default: bool = False) -> bool:
+    proceed = input(f'{message} ({Fore.YELLOW}{"Y/n" if yes_by_default else "y/N"}{Style.RESET_ALL}): ')
+    if yes_by_default:
+        return proceed.lower() != 'n'
+    else:
+        return proceed.lower() == 'y'
+
+
 def print_used_value(description: str, value: str):
     print(f'{description}: {Fore.GREEN}{value}{Style.RESET_ALL}')
 
@@ -56,3 +65,7 @@ def write_file(name: str, content: any):
     f = open(name, "w")
     f.write(content)
     f.close()
+
+
+def enter_to_continue():
+    input(f'Press {Back.YELLOW}Enter{Style.RESET_ALL} to continue')
